'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

exports.default = diff;

var _immutable = require('immutable');

var _immutable2 = _interopRequireDefault(_immutable);

var _normalize = require('./normalize');

var _normalize2 = _interopRequireDefault(_normalize);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Compares two maps of files. Returns a new immutable map containing only the
 * changes that need to be applied to `input` to get to `output`. This can
 * include `null` values indicating 'deletions' (for keys that are present in
 * the input map but not the output map).
 */

function diff(_input, _output) {
  var input = (0, _normalize2.default)(_input);
  var output = (0, _normalize2.default)(_output);

  var inputKeys = _immutable2.default.Set.fromKeys(input);
  var outputKeys = _immutable2.default.Set.fromKeys(output);

  var changes = {};

  // include any output files that are newly created/modified
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = (0, _getIterator3.default)(outputKeys), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var outputKey = _step.value;

      var outputValue = output.get(outputKey);
      var inputValue = input.get(outputKey);

      if (!inputValue || !outputValue.equals(inputValue)) {
        changes[outputKey] = outputValue;
      }
    }

    // add nulls for anything that has been deleted
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  var _iteratorNormalCompletion2 = true;
  var _didIteratorError2 = false;
  var _iteratorError2 = undefined;

  try {
    for (var _iterator2 = (0, _getIterator3.default)(inputKeys), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
      var inputKey = _step2.value;

      if (!output.has(inputKey)) changes[inputKey] = null;
    }
  } catch (err) {
    _didIteratorError2 = true;
    _iteratorError2 = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion2 && _iterator2.return) {
        _iterator2.return();
      }
    } finally {
      if (_didIteratorError2) {
        throw _iteratorError2;
      }
    }
  }

  return _immutable2.default.Map(changes);
}
//# sourceMappingURL=diff.js.map