'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

exports.default = normalize;

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _immutable = require('immutable');

var _immutable2 = _interopRequireDefault(_immutable);

var _lodash = require('lodash');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function normalize(_files) {
  var files = _files;

  if (_immutable2.default.Map.isMap(files)) {
    // return fast if it's already been branded as normalized
    if (files.__exhibitNormalized === true) return files;

    // make `files` into a mutable plain object, if not already
    files = files.toObject();
  } else if (!(0, _lodash.isPlainObject)(files)) {
    throw new TypeError('Expected files to be an Immutable Map or a plain object');
  }

  // validate/normalize all keys and values
  var keys = (0, _keys2.default)(files);
  for (var i = 0, l = keys.length; i < l; i++) {
    var key = keys[i];

    // normalize the key as a path (handle .. etc)
    var normalizedKey = _path2.default.normalize(key);
    if (key !== normalizedKey) {
      files[normalizedKey] = files[key];
      delete files[key];
    }

    // ensure the value is a buffer
    var value = files[normalizedKey];
    if (!Buffer.isBuffer(value)) {
      if (typeof value === 'string') files[normalizedKey] = new Buffer(value);else throw new TypeError('Expected all values to be buffers or strings');
    }
  }

  // return it as an immutable map, branded as being normalized
  var result = _immutable2.default.Map(files);
  Object.defineProperty(result, '__exhibitNormalized', { value: true });
  return result;
} /**
   * Synchronously validates and normalizes a `files` object.
   *
   * Expects an Immutable Map or a plain object, and returns an Immutable Map
   * (guaranteeing that the keys are all normalized file paths and the values
   * are all buffers).
   *
   * If any key is not a string, or any value is not a buffer/string, this
   * function will throw.
   */
//# sourceMappingURL=normalize.js.map