'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = plugin;

var _stackTrace = require('stack-trace');

var _stackTrace2 = _interopRequireDefault(_stackTrace);

var _resolveFrom = require('resolve-from');

var _resolveFrom2 = _interopRequireDefault(_resolveFrom);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _chalk = require('chalk');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Utility function for loading a plugin and invoking it to configure and return a builder function.
 *
 * These are functionally equivalent:
 * - `plugin('foo', 1, 2)`
 * - `require('exhibit-plugin-foo')(1, 2)`
 */

function plugin(name) {
  var callingFile = _stackTrace2.default.get()[1].getFileName();
  var pluginPath = (0, _resolveFrom2.default)(_path2.default.dirname(callingFile), 'exhibit-plugin-' + name);

  if (!pluginPath) {
    console.error((0, _chalk.red)('\n\nCould not find plugin: ' + name) + '\n\nIf this plugin is published on npm, you can install it like this:\n\n' + (0, _chalk.cyan)('  npm install -D exhibit-plugin-' + name + '\n\n'));

    throw new Error('Exhibit plugin not found: exhibit-plugin-' + name);
  }

  var loadedPlugin = require(pluginPath);

  for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    args[_key - 1] = arguments[_key];
  }

  return (loadedPlugin.default || loadedPlugin).apply(undefined, args);
}
//# sourceMappingURL=plugin.js.map